# Metahyper

Parallelisation and distribution framework for neural pipeline search algorithms.

Features:

- Asynchronous parallelization and distribution
- Fault tolerance for crashes and job time limits
- Agnostic to search space, objective functions, ...

![Python versions](https://img.shields.io/badge/python-3.7%20%7C%203.8%20%7C%203.9%20%7C%203.10-informational)
[![License](https://img.shields.io/badge/license-MIT-informational)](LICENSE)

## Installation

Using pip

```bash
pip install metahyper
```

## Usage

Please see our examples in [metahyper_examples](metahyper_examples).

## Contributing

Please see our guidelines and guides for contributors at [CONTRIBUTING.md](CONTRIBUTING.md).
